{% extends "saas_emails/base.html" %}

{% block title %}Registration Code{% endblock %}

{% block content %}
  <p>Welcome to {{ site.name }}!</p>

  <p>We're excited to have you on board. To finalize your account sign-up and
  ensure the utmost security for your data, we kindly ask you to complete
  the verification process by entering the provided verification code.</p>

  <p>Your Verification Code:</p>

  {% include "saas_emails/partials/auth_code.html" %}

  <p>If you did not initiate this registration, please disregard this email.</p>

  <p>Feel free to reach out if you have any questions or concerns. We're here to assist you!</p>
{% endblock %}
