<table role="presentation" border="0" cellpadding="0" cellspacing="0" class="auth-code">
  <tbody>
  <tr>
    <td align="left">
      <table role="presentation" border="0" cellpadding="0" cellspacing="0">
        <tbody>
        <tr>
          <td><code>{{ code }}</code></td>
        </tr>
        </tbody>
      </table>
    </td>
  </tr>
  </tbody>
</table>
